pub struct Responsive {
pub config: ResponsiveConfig,
pub current_breakpoint: Breakpoint,
}Expand description
Re-export core tailwind-rs functionality Main responsive struct that uses the configuration
Fields
config: ResponsiveConfigThe configuration
current_breakpoint: BreakpointCurrent breakpoint
Implementations
Sourceimpl Responsive
impl Responsive
Sourcepub fn new() -> Responsive
pub fn new() -> Responsive
Create a new responsive instance
Sourcepub fn with_config(config: ResponsiveConfig) -> Responsive
pub fn with_config(config: ResponsiveConfig) -> Responsive
Create a responsive instance with custom configuration
Sourcepub fn get_current_breakpoint(&self) -> Breakpoint
pub fn get_current_breakpoint(&self) -> Breakpoint
Get the current breakpoint
Sourcepub fn set_current_breakpoint(&mut self, breakpoint: Breakpoint)
pub fn set_current_breakpoint(&mut self, breakpoint: Breakpoint)
Set the current breakpoint
Sourcepub fn get_config(&self) -> &ResponsiveConfig
pub fn get_config(&self) -> &ResponsiveConfig
Get the configuration
Sourcepub fn update_config(&mut self, config: ResponsiveConfig)
pub fn update_config(&mut self, config: ResponsiveConfig)
Update the configuration
Sourcepub fn is_breakpoint_active(
&self,
breakpoint: Breakpoint,
screen_width: u32,
) -> bool
pub fn is_breakpoint_active( &self, breakpoint: Breakpoint, screen_width: u32, ) -> bool
Check if a breakpoint is active for the current screen width
Sourcepub fn get_breakpoint_for_width(&self, screen_width: u32) -> Breakpoint
pub fn get_breakpoint_for_width(&self, screen_width: u32) -> Breakpoint
Get the appropriate breakpoint for a given screen width